Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2012-08-12 01:35:24 +0400
committerCampbell Barton <ideasman42@gmail.com>2012-08-12 01:35:24 +0400
commitc567cf3fab5b962a4166ef44f45c80941021b60d (patch)
treef3b257cdd6ec3c6241395ca2bb815cc82a428506 /source/creator
parentf2d06dc257ec9c4667fd9964243b032fed2d21c3 (diff)
code cleanup: WM naming conventions
Diffstat (limited to 'source/creator')
-rw-r--r--source/creator/creator.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/source/creator/creator.c b/source/creator/creator.c
index 26e5e16af48..3e884d1aa38 100644
--- a/source/creator/creator.c
+++ b/source/creator/creator.c
@@ -480,20 +480,20 @@ static int prefsize(int argc, const char **argv, void *UNUSED(data))
sizx = atoi(argv[3]);
sizy = atoi(argv[4]);
- WM_setprefsize(stax, stay, sizx, sizy);
+ WM_init_state_size_set(stax, stay, sizx, sizy);
return 4;
}
static int with_borders(int UNUSED(argc), const char **UNUSED(argv), void *UNUSED(data))
{
- WM_setinitialstate_normal();
+ WM_init_state_normal_set();
return 0;
}
static int without_borders(int UNUSED(argc), const char **UNUSED(argv), void *UNUSED(data))
{
- WM_setinitialstate_fullscreen();
+ WM_init_state_fullscreen_set();
return 0;
}
@@ -1029,7 +1029,7 @@ static int load_file(int UNUSED(argc), const char **argv, void *data)
return -1;
}
/* WM_read_file() runs normally but since we're in background mode do here */
#ifdef WITH_PYTHON
/* run any texts that were loaded in and flagged as modules */
BPY_driver_reset();
@@ -1046,7 +1046,7 @@ static int load_file(int UNUSED(argc), const char **argv, void *data)
* a file - this should do everything a 'load file' does */
ReportList reports;
BKE_reports_init(&reports, RPT_PRINT);
- WM_read_file(C, filename, &reports);
+ WM_file_read(C, filename, &reports);
BKE_reports_clear(&reports);
}
@@ -1029,7 +1029,7 @@ static int load_file(int UNUSED(argc), const char **argv, void *data)
return -1;
}
- /* WM_read_file() runs normally but since we're in background mode do here */
+ /* WM_file_read() runs normally but since we're in background mode do here */
#ifdef WITH_PYTHON
/* run any texts that were loaded in and flagged as modules */